@@ -4,8 +4,8 @@
 *  common.h:  Basic program specific statements, macros and typedefs...
 *
 *
-*  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
-*  Copyright (c) 2010 Free Software Foundation, Inc.
+*  Copyright (c) 1994, 95, 96, 1997, 2000, 2011 Thomas Esken
+*  Copyright (c) 2010, 2011 Free Software Foundation, Inc.
 *
 *  This software doesn't claim completeness, correctness or usability.
 *  On principle I will not be liable for ANY damages or losses (implicit
@@ -34,6 +34,14 @@
 /*
 *  Include (sub)header files   ;<
 */
+# if USE_UNICODE
+#  include "unistdio.h"
+#  include "unistr.h"
+#  undef sprintf
+#  define sprintf u8_sprintf
+#  undef strlen
+#  define strlen u8_strlen
+# endif
 # if HAVE_STDIO_H || STDC_HEADERS
 #  include <stdio.h>
 # endif
@@ -428,11 +436,6 @@ extern char *getenv __P_ ((const char *env_var));
 /* Argument separator of a long option, e.g. `--foo=BAR'. */
 # define LARG_SEP        "="
 
-/* 3 chars text of a symbolic long option argument shown in help pages. */
-# if USE_DE
-#  define LARG_TXT        "ARG"
-# endif
-
 
 
 /*
@@ -692,24 +695,6 @@ extern char *getenv __P_ ((const char *env_var));
 /* Fixed length field format. */
 # define FFIX_CHAR     '#'
 
-
-
-/*
-*  German language dependent preprocessor statements.
-*/
-# if USE_DE
-/* Time separator used for displaying HH:MM. */
-#  define TIME_SEP       DEFAULT_TIME_SEP
-#  define RESPONSE_TXT   "Antwortdatei"
-#  define CREATED_TXT    "Erzeugt"
-#  define INTERNAL_TXT   "Intern"
-#  ifdef GCAL_SHELL
-#   define SCRIPT_TXT     "shell script"
-#  endif
-# endif	/* USE_DE */
-
-
-
 /*
 *  Important preprocessor symbols for the internal ranges.
 */
@@ -791,9 +776,12 @@ extern char *getenv __P_ ((const char *env_var));
 /*
 *  And last but not least...
 */
-# define COPYRIGHT_TXT    "Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken"
-# define BUG_REPORT_ADR1  "esken@gmx.net"
-# define BUG_REPORT_ADR2  "bug-gcal@gnu.org"
+# define COPYRIGHT_TXT    "Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken\n" \
+"Copyright (c) 2010, 2011 Free Software Foundation, Inc."
+# define BUG_REPORT_ADR1  "bug-gcal@gnu.org"
+
+# define HOMEPAGE "http://www.gnu.org/software/gcal"
+# define HOMEPAGE_GNU_SOFTWARE "http://www.gnu.org/gethelp/"
 
 
 
