@@ -3,7 +3,7 @@
 *
 *
 *  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
-*  Copyright (c) 2010 Free Software Foundation, Inc.
+*  Copyright (c) 2010, 2011 Free Software Foundation, Inc.
 *
 *  This software doesn't claim completeness, correctness or usability.
 *  On principle I will not be liable for ANY damages or losses (implicit
@@ -207,8 +207,7 @@ equinox_solstice (longitude, day, month, year, hour, min)
 
 
 
-double delta_t
-__P_ ((day, month, year, hour, min))
+double delta_t (day, month, year, hour, min)
      const int day;
      const int month;
      const int year;
